==> eav_field-2.0.0.tar.gz: eav_field/src/EavAttributeStorage.php <==
<?php

namespace Drupal\eav_field;

use Drupal\Core\Entity\Query\QueryInterface;
use Drupal\Core\Entity\Sql\SqlContentEntityStorage;
use Drupal\eav_field\Entity\EavAttribute;
use Drupal\taxonomy\TermStorageInterface;

class EavAttributeStorage extends SqlContentEntityStorage {

  /**
   * Load attributes by properties.
   *
   * @return EavAttribute[]
   */
  public function loadByProperties(array $values = [], $alter_callback = NULL) {
    // @see \Drupal\Core\Entity\EntityStorageBase::buildPropertyQuery()
    $entity_query = $this->getQuery();
    $entity_query->accessCheck(FALSE);
    $entity_query->sort('weight');
    $this->buildPropertyQuery($entity_query, $values);

    if (is_callable($alter_callback)) {
      $alter_callback($entity_query);
    }

    $result = $entity_query->execute();
    return $result ? $this->loadMultiple($result) : [];
  }

  /**
   * Load attributes by category.
   *
   * @param integer|array|NULL $category Category id, array of ids or NULL for load global attributes.
   * @param boolean $including_parents Set TRUE if need including parents categories.
   *
   * @return EavAttribute[]
   */
  public function loadByCategory($category, $including_parents = TRUE) {
    if ($category) {
      if (!is_array($category)) {
        $category = [$category];
      }

      if ($including_parents) {
        $term_storage = $this->entityTypeManager->getStorage('taxonomy_term'); /** @var TermStorageInterface $term_storage */
        foreach ($category as $category_id) {
          if ($category_all_parents = $term_storage->loadAllParents($category_id)) {
            $category = array_merge($category, array_keys($category_all_parents));
          }
        }
        $category = array_unique($category);
      }

      return $this->loadByProperties(['category' => $category]);
    }

    return $this->loadByProperties([], function (QueryInterface $entity_query) {
      $entity_query->notExists('category');
    });
  }

}

==> eav_field-2.0.1.tar.gz: eav_field/src/EavAttributeStorage.php <==
<?php

namespace Drupal\eav_field;

use Drupal\Core\Entity\Query\QueryInterface;
use Drupal\Core\Entity\Sql\SqlContentEntityStorage;
use Drupal\eav_field\Entity\EavAttribute;
use Drupal\taxonomy\TermStorageInterface;

class EavAttributeStorage extends SqlContentEntityStorage {

  /**
   * Load attributes by properties.
   *
   * @return EavAttribute[]
   */
  public function loadByProperties(array $values = [], $alter_callback = NULL) {
    // @see \Drupal\Core\Entity\EntityStorageBase::buildPropertyQuery()
    $entity_query = $this->getQuery();
    $entity_query->accessCheck(FALSE);
    $entity_query->sort('weight');
    $this->buildPropertyQuery($entity_query, $values);

    if (is_callable($alter_callback)) {
      $alter_callback($entity_query);
    }

    $result = $entity_query->execute();
    return $result ? $this->loadMultiple($result) : [];
  }

  /**
   * Load attributes by category.
   *
   * @param integer|array|NULL $category Category id, array of ids or NULL for load global attributes.
   * @param boolean $including_parents Set TRUE if need including parents categories.
   *
   * @return EavAttribute[]
   */
  public function loadByCategory($category, $including_parents = TRUE): array {
    if ($category) {
      if (!is_array($category)) {
        $category = [$category];
      }

      if ($including_parents) {
        $term_storage = $this->entityTypeManager->getStorage('taxonomy_term'); /** @var TermStorageInterface $term_storage */
        foreach ($category as $category_id) {
          if ($category_all_parents = $term_storage->loadAllParents($category_id)) {
            $category = array_merge($category, array_keys($category_all_parents));
          }
        }
        $category = array_unique($category);
      }

      return $this->loadByProperties(['category' => $category]);
    }

    return $this->loadByProperties([], function (QueryInterface $entity_query) {
      $entity_query->notExists('category');
    });
  }

}
